@@ -1,4 +1,4 @@
-### PKindex is usually the Dataset.
+### PKindex is the target Dataset.
 
 
 ### Normal fitting
@@ -18,7 +18,7 @@ ffirst.lag<- function(PKindex,
    ## Input dose and Tlag and initial value for ka, kel and Vd
 
    if (is.null(Dose)) {
-     cat("Enter Dose value\n")
+     cat("Enter Dose\n")
      Dose <- scan(nlines=1,quiet=TRUE)
    } 
    else {
@@ -26,7 +26,7 @@ ffirst.lag<- function(PKindex,
    }
 
    if ( Tlag ){
-       cat("\nEnter lag time value\n")
+       cat("\nEnter the lag time value:\n")
        Tlag<-scan(nlines=1,quiet=TRUE)
        cat("\n")
    } 
@@ -41,7 +41,7 @@ ffirst.lag<- function(PKindex,
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -64,7 +64,7 @@ ffirst.lag<- function(PKindex,
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -159,7 +159,7 @@ ffirst.lag<- function(PKindex,
                Domains=matrix(c(0.01,0.01,1,10,1,100),3,2),
                MemoryMatrix=TRUE)
       }
-      cat("<< The value of parameter obtained from genetic algorithm >>\n\n")
+      cat("<< PK parameters obtained from genetic algorithm >>\n\n")
       if (MMe) {
         namegen<-c("ka","Vm","Km","Vd")
         outgen<-c(gen$par[1],gen$par[2],gen$par[3],gen$par[4])
@@ -183,9 +183,9 @@ ffirst.lag<- function(PKindex,
         outopt<-c(opt$par[1],opt$par[2],opt$par[3])
       }
       
-      cat("\n<< The value of parameter fitted by Nelder-Mead Simplex slgorithm >>\n\n")
+      cat("\n<< PK parameters obtained from Nelder-Mead Simplex algorithm >>\n\n")
       print(data.frame(Parameter=nameopt,Value=outopt))
-      cat("\n<< Residual sum-of-squares and parameter values fitted by nls >>\n\n")
+      cat("\n<< Residual sum-of-square (RSS) and final PK parameters with nls >>\n\n")
       
       if (MMe) {
         fm<-nls(conc ~ modfun2(time, ka, Vm, Km, Vd), data=PKindex,subset=Subject==i,
@@ -235,7 +235,7 @@ ffirst.nolag<- function(PKindex,
    ## Input dose and Tlag and initial value for ka, kel and Vd
 
    if (is.null(Dose)) {
-     cat("Enter Dose value\n")
+     cat("Enter Dose\n")
      Dose <- scan(nlines=1,quiet=TRUE)
    } 
    else {
@@ -252,7 +252,7 @@ ffirst.nolag<- function(PKindex,
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -275,7 +275,7 @@ ffirst.nolag<- function(PKindex,
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -359,7 +359,7 @@ ffirst.nolag<- function(PKindex,
                Domains=matrix(c(0.01,0.01,1,10,1,100),3,2),
                MemoryMatrix=TRUE)
       }
-      cat("<< The value of parameter obtained from genetic algorithm >>\n\n")
+      cat("<< PK parameters obtained from genetic algorithm >>\n\n")
       if (MMe) {
         namegen<-c("ka","Vm","Km","Vd")
         outgen<-c(gen$par[1],gen$par[2],gen$par[3],gen$par[4])
@@ -383,9 +383,9 @@ ffirst.nolag<- function(PKindex,
         outopt<-c(opt$par[1],opt$par[2],opt$par[3])
       }
       
-      cat("\n<< The value of parameter fitted by Nelder-Mead Simplex slgorithm >>\n\n")
+      cat("\n<< PK parameters obtained from Nelder-Mead Simplex algorithm >>\n\n")
       print(data.frame(Parameter=nameopt,Value=outopt))
-      cat("\n<< Residual sum-of-squares and parameter values fitted by nls >>\n\n")
+      cat("\n<< Residual sum-of-square (RSS) and final PK parameters with nls >>\n\n")
       
       if (MMe) {
         fm<-nls(conc ~ modfun4(time, ka, Vm, Km, Vd), data=PKindex,subset=Subject==i,
@@ -429,7 +429,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
    #options(warn=-1)
    
    if (is.null(Subject) || !is.integer(Subject)) {
-     cat("How many subject do you want?\n")
+     cat("How many subjects do you want?\n")
      Subject<-scan(nlines=1,quiet=TRUE)
    }
 
@@ -443,7 +443,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
    show(PKtime)
 
    if (is.null(Dose)) {
-     cat("\nEnter dose value\n")
+     cat("\nEnter dose\n")
      Dose<-scan(nlines=1,quiet=TRUE)
    }
   
@@ -461,7 +461,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -496,7 +496,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -572,22 +572,22 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
    
    file.menu <- c("Simulation with Error",
                   "Monte Carlo Simulation")
-   pick <- menu(file.menu, title = "<< Simulation Type >>")
+   pick <- menu(file.menu, title = "<< Simulation Types >>")
    if (pick ==1){
       cat("\n\n")
       file.menu <- c("No Error",
-                     "Error=Normal Error", 
-                     "Error=Uniform Error",
-                     "Error=Normal Error*True Value",
-                     "Error=Uniform Error*True Value")
-      pick <- menu(file.menu, title = "<< Error Type >>")   
+                     "Error = Normal Error", 
+                     "Error = Uniform Error",
+                     "Error = Normal Error*True Value",
+                     "Error = Uniform Error*True Value")
+      pick <- menu(file.menu, title = "<< Error Types >>")   
       
       type<-switch(pick, 
                   "No Error",
-                  "Error=Normal Error", 
-                  "Error=Uniform Error",
-                  "Error=Normal Error*True Value",
-                  "Error=Uniform Error*True Value")
+                  "Error = Normal Error", 
+                  "Error = Uniform Error",
+                  "Error = Normal Error*True Value",
+                  "Error = Uniform Error*True Value")
       
       if (pick ==1){
           PKindex<-vector(Subject,mode="list")
@@ -621,7 +621,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -638,7 +638,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -655,7 +655,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -720,7 +720,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -737,7 +737,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -754,7 +754,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -771,7 +771,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -847,19 +847,19 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
   } 
   else if (pick ==2){ 
      cat("\n\n")
-     file.menu <- c("Error=Normal Error", 
-                    "Error=Uniform Error",
-                    "Error=Normal Error*True Value",
-                    "Error=Uniform Error*True Value")
-     pick <- menu(file.menu, title = "<< Error Type >>")
+     file.menu <- c("Error = Normal Error", 
+                    "Error = Uniform Error",
+                    "Error = Normal Error*True Value",
+                    "Error = Uniform Error*True Value")
+     pick <- menu(file.menu, title = "<< Error Types >>")
      
      type<-switch(pick, 
-                  "Error=Normal Error", 
-                  "Error=Uniform Error",
-                  "Error=Normal Error*True Value",
-                  "Error=Uniform Error*True Value")
+                  "Error = Normal Error", 
+                  "Error = Uniform Error",
+                  "Error = Normal Error*True Value",
+                  "Error = Uniform Error*True Value")
      
-     cat("\n\nHow many times do you want to iteration ?\n")
+     cat("\n\nHow many interations do you want to run?\n")
      re<-scan(nlines=1,quiet=TRUE)
      
        if (MMe ){
@@ -871,7 +871,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -888,7 +888,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -905,7 +905,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -922,7 +922,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -941,7 +941,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
           cat("Error Type:", type,"                                                    \n")
           cat("Simulation #:", re,"                                                    \n\n")
           sim<-matrix(c(par1,par2,par3,par4,factor1,factor2,factor3,factor4),4,2)
-          dimnames(sim)<-list(c("ka","Vm","Km","Vd"),c("Original","Error factor"))
+          dimnames(sim)<-list(c("ka","Vm","Km","Vd"),c("Selected","Error factor"))
           show(sim)   
           cat("************************************************************************\n\n")
          }
@@ -963,7 +963,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
           cat("Error Type:", type,"                                                     \n")
           cat("Simulation #:", re,"                                                     \n\n")
           sim<-matrix(c(par1,par2,par3,par4,factor1,factor2,factor3,factor4),4,2)
-          dimnames(sim)<-list(c("ka","Vm","Km","Vd"),c("Original","Error factor"))
+          dimnames(sim)<-list(c("ka","Vm","Km","Vd"),c("Selected","Error factor"))
           show(sim)   
           cat("*************************************************************************\n\n")
          }
@@ -985,7 +985,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
          cat("Error Type:", type,"                                \n")
          cat("Simulation #:", re,"                                \n\n")
          sim<-matrix(c(par1,par2,par3,factor1,factor2,factor3),3,2)
-         dimnames(sim)<-list(c("ka","kel","Vd"),c("Original","Error factor"))
+         dimnames(sim)<-list(c("ka","kel","Vd"),c("Selected","Error factor"))
          show(sim)   
          cat("****************************************************\n\n")
          }
@@ -1005,7 +1005,7 @@ sfirst.nolag <- function(Subject=NULL,  # N Subj's
          cat("Error Type:", type,"                                   \n")
          cat("Simulation #:", re,"                                   \n\n")
          sim<-matrix(c(par1,par2,par3,factor1,factor2,factor3),3,2)
-         dimnames(sim)<-list(c("ka","kel","Vd"),c("Original","Error factor"))
+         dimnames(sim)<-list(c("ka","kel","Vd"),c("Selected","Error factor"))
          show(sim)   
          cat("*******************************************************\n\n")
          }
