@@ -1,4 +1,4 @@
-### PKindex is usually the Dataset.
+### PKindex is the target Dataset.
 
 
 ### Normal fitting
@@ -16,7 +16,7 @@ finfu1 <- function(PKindex,
   ## Input dose and Tinf and initial value for kel and Vd
 
   if (is.null(Dose)) {
-    cat("Enter Dose value\n")
+    cat("Enter Dose\n")
     Dose <- scan(nlines=1,quiet=TRUE)
   } 
   else {
@@ -41,7 +41,7 @@ finfu1 <- function(PKindex,
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -66,7 +66,7 @@ finfu1 <- function(PKindex,
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -154,7 +154,7 @@ finfu1 <- function(PKindex,
                 Domains=matrix(c(0.01,0.01,100,100),2,2),
                 MemoryMatrix=TRUE)
       }
-     cat("<< The value of parameter obtained from genetic algorithm >>\n\n")
+     cat("<< PK parameters obtained from genetic algorithm >>\n\n")
      if (MMe) {
         namegen<-c("Vm","Km","Vd")
         outgen<-c(gen$par[1],gen$par[2],gen$par[3])
@@ -178,9 +178,9 @@ finfu1 <- function(PKindex,
         outopt<-c(opt$par[1],opt$par[2])
      }
 
-     cat("\n<< The value of parameter fitted by Nelder-Mead Simplex slgorithm >>\n\n")
+     cat("\n<< PK parameters obtained from Nelder-Mead Simplex algorithm >>\n\n")
      print(data.frame(Parameter=nameopt,Value=outopt))
-     cat("\n<< Residual sum-of-squares and parameter values fitted by nls >>\n\n")
+     cat("\n<< Residual sum-of-square (RSS) and final PK parameters with nls >>\n\n")
 
      if (MMe) {
         fm<-nls(conc~modfun2(time,Vm,Km,Vd),data=PKindex,subset=Subject==i,
@@ -227,7 +227,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
   #options(warn=-1)
   
   if (is.null(Subject) || !is.integer(Subject)) {
-     cat("How many subject do you want?\n")
+     cat("How many subjects do you want?\n")
      Subject<-scan(nlines=1,quiet=TRUE)
   }
 
@@ -241,7 +241,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
   show(PKtime)
 
   if (is.null(Dose)) {
-    cat("\nEnter dose value\n")
+    cat("\nEnter dose\n")
     Dose<-scan(nlines=1,quiet=TRUE)
   }
 
@@ -260,7 +260,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -291,7 +291,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
              cat("\n")
              cat("**********************************\n")
              cat(" Parameter value can not be zero. \n")
-             cat(" Press enter to continue.         \n")
+             cat(" Press Enter to continue.         \n")
              cat("**********************************\n\n")
              readline()
              cat("\n")
@@ -336,22 +336,22 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
   
   file.menu <- c("Simulation with Error",
                  "Monte Carlo Simulation")
-  pick <- menu(file.menu, title = "<< Simulation Type >>")
+  pick <- menu(file.menu, title = "<< Simulation Types >>")
   if (pick ==1){
      cat("\n\n")
      file.menu <- c("No Error",
-                    "Error=Normal Error", 
-                    "Error=Uniform Error",
-                    "Error=Normal Error*True Value",
-                    "Error=Uniform Error*True Value")
-     pick <- menu(file.menu, title = "<< Error Type >>")    
+                    "Error = Normal Error", 
+                    "Error = Uniform Error",
+                    "Error = Normal Error*True Value",
+                    "Error = Uniform Error*True Value")
+     pick <- menu(file.menu, title = "<< Error Types >>")    
      
      type<-switch(pick, 
                   "No Error",
-                  "Error=Normal Error", 
-                  "Error=Uniform Error",
-                  "Error=Normal Error*True Value",
-                  "Error=Uniform Error*True Value")
+                  "Error = Normal Error", 
+                  "Error = Uniform Error",
+                  "Error = Normal Error*True Value",
+                  "Error = Uniform Error*True Value")
        
        if (pick ==1){
          PKindex<-vector(Subject,mode="list")
@@ -383,7 +383,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -400,7 +400,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -453,7 +453,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -470,7 +470,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -487,7 +487,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -552,19 +552,19 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
   } 
   else if (pick ==2){ 
      cat("\n\n")
-     file.menu <- c("Error=Normal Error", 
-                    "Error=Uniform Error",
-                    "Error=Normal Error*True Value",
-                    "Error=Uniform Error*True Value")
-     pick <- menu(file.menu, title = "<< Error Type >>")
+     file.menu <- c("Error = Normal Error", 
+                    "Error = Uniform Error",
+                    "Error = Normal Error*True Value",
+                    "Error = Uniform Error*True Value")
+     pick <- menu(file.menu, title = "<< Error Types >>")
      
      type<-switch(pick, 
-                  "Error=Normal Error", 
-                  "Error=Uniform Error",
-                  "Error=Normal Error*True Value",
-                  "Error=Uniform Error*True Value")
+                  "Error = Normal Error", 
+                  "Error = Uniform Error",
+                  "Error = Normal Error*True Value",
+                  "Error = Uniform Error*True Value")
      
-     cat("\n\nHow many times do you want to iteration ?\n")
+     cat("\n\nHow many interations do you want to run?\n")
      re<-scan(nlines=1,quiet=TRUE)
      
        if (! MMe){
@@ -575,7 +575,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -592,7 +592,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                 cat("\n")
                 cat("**********************************\n")
                 cat(" Parameter value can not be zero. \n")
-                cat(" Press enter to continue.         \n")
+                cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
@@ -610,7 +610,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
          cat("Error Type:", type,"                                   \n")
          cat("Simulation #:", re,"                                   \n\n")
          sim<-matrix(c(par1,par2,factor1,factor2),2,2)
-         dimnames(sim)<-list(c("kel","Vd"),c("Original","Error factor"))
+         dimnames(sim)<-list(c("kel","Vd"),c("Selected","Error factor"))
          show(sim)   
          cat("*******************************************************\n\n")
        }
@@ -630,7 +630,7 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
          cat("Error Type:", type,"                            \n")
          cat("Simulation #:", re,"                            \n\n")
          sim<-matrix(c(par1,par2,par3,factor1,factor2,factor3),3,2)
-         dimnames(sim)<-list(c("Vm","Km","Vd"),c("Original","Error factor"))
+         dimnames(sim)<-list(c("Vm","Km","Vd"),c("Selected","Error factor"))
          show(sim)   
          cat("************************************************\n\n")
        }
