@@ -2,16 +2,14 @@
 
    # echo output to screen
    cat("\n")
-   cat("*********************************************************\n")
+   cat("*********************** PKfit v1.1.7 *********************\n")
    cat("   Please type 'PKmenu()' to get started.                \n")
    cat("                                                         \n")
-   cat("   If you want to see some demos,                         \n")
-   cat("                                                         \n")
-   cat("   Please type                                           \n")
+   cat("   If you want to see some demos, type                   \n")
    cat("                                                         \n")
    cat("   'demo(iv.bolus)' for Normal Fitting.                  \n")
    cat("                                                         \n")
-   cat("   'demo(mcsim)' for Monte Carlo Simulation of 200 runs. \n")
+   cat("   'demo(mcsim)' for Monte-Carlo Simulation of 200 runs. \n")
    cat("                                                         \n")
    cat("   'demo(mmpk)' for Michaelis-Menten Model.              \n")
    cat("*********************************************************\n\n")
